@@ -36,8 +36,8 @@ public:
 #if QWT_VERSION < 0x060000
     virtual QwtDoubleInterval range() const;
     virtual void setRange(const QwtDoubleInterval&);
-#else
-    virtual QwtInterval interval(Qt::Axis) const;
+#elif QWT_VERSION >= 0x060200
+    virtual QwtInterval interval(Qt::Axis) const override;
     void setInterval(Qt::Axis, const QwtInterval&);
 #endif
 
@@ -51,15 +51,18 @@ public:
     void incrementResidual();
 
 protected:
-    double* d_data;
+    std::vector<double> d_data;
     double d_rows, d_cols;
     double d_resid;
-    int d_nitems, d_totalitems, d_data_size;
+    int d_nitems, d_totalitems;
 
 #if QWT_VERSION < 0x060000
     QwtDoubleInterval d_intensityRange;
 #else
     QwtInterval d_intensityRange;
+#endif
+
+#if QWT_VERSION >= 0x060200
     QwtInterval d_intervals[3];
 #endif
 
